@@ -12,7 +12,7 @@ mod wire_msg_header;
 use self::wire_msg_header::{MessageKind, WireMsgHeader};
 #[cfg(not(feature = "client-only"))]
 use super::node;
-use super::{client, section_info, DestInfo, Error, MessageType, Result};
+use super::{client, section_info, DestInfo, Error, MessageId, MessageType, Result};
 use bytes::Bytes;
 use cookie_factory::{combinator::slice, gen};
 use std::fmt::Debug;
@@ -30,14 +30,6 @@ pub struct WireMsg {
 }
 
 impl WireMsg {
-    /// Creates a new instance of a 'Ping' message.
-    pub fn new_ping_msg(dest: XorName, dest_section_pk: PublicKey) -> Self {
-        Self {
-            header: WireMsgHeader::new(MessageKind::Ping, dest, dest_section_pk, None),
-            payload: Bytes::new(),
-        }
-    }
-
     /// Creates a new instance keeping a (serialized) copy of the 'SectionInfo' message provided.
     pub fn new_section_info_msg(
         query: &section_info::Message,
@@ -52,7 +44,13 @@ impl WireMsg {
         })?;
 
         Ok(Self {
-            header: WireMsgHeader::new(MessageKind::SectionInfo, dest, dest_section_pk, None),
+            header: WireMsgHeader::new(
+                MessageId::new(),
+                MessageKind::SectionInfo,
+                dest,
+                dest_section_pk,
+                None,
+            ),
             payload: Bytes::from(payload_vec),
         })
     }
@@ -72,7 +70,7 @@ impl WireMsg {
         })?;
 
         Ok(Self {
-            header: WireMsgHeader::new(MessageKind::Client, dest, dest_section_pk, None),
+            header: WireMsgHeader::new(msg.id(), MessageKind::Client, dest, dest_section_pk, None),
             payload: Bytes::from(payload_vec),
         })
     }
@@ -92,7 +90,13 @@ impl WireMsg {
         })?;
 
         Ok(Self {
-            header: WireMsgHeader::new(MessageKind::Routing, dest, dest_section_pk, None),
+            header: WireMsgHeader::new(
+                MessageId::new(),
+                MessageKind::Routing,
+                dest,
+                dest_section_pk,
+                None,
+            ),
             payload: Bytes::from(payload_vec),
         })
     }
@@ -113,7 +117,13 @@ impl WireMsg {
         })?;
 
         Ok(Self {
-            header: WireMsgHeader::new(MessageKind::Node, dest, dest_section_pk, src_section_pk),
+            header: WireMsgHeader::new(
+                msg.id(),
+                MessageKind::Node,
+                dest,
+                dest_section_pk,
+                src_section_pk,
+            ),
             payload: Bytes::from(payload_vec),
         })
     }
@@ -154,7 +164,6 @@ impl WireMsg {
         };
 
         match self.header.kind() {
-            MessageKind::Ping => Ok(MessageType::Ping(dest_info)),
             MessageKind::SectionInfo => {
                 let msg: section_info::Message =
                     rmp_serde::from_slice(&self.payload).map_err(|err| {
@@ -210,6 +219,11 @@ impl WireMsg {
         }
     }
 
+    /// Return the message id of this message
+    pub fn msg_id(&self) -> MessageId {
+        self.header.msg_id()
+    }
+
     /// Return the destination section PublicKey for this message
     pub fn dest_section_pk(&self) -> PublicKey {
         self.header.dest_section_pk()
@@ -293,32 +307,6 @@ mod tests {
     use threshold_crypto::SecretKey;
     use xor_name::XorName;
 
-    #[test]
-    fn serialisation_ping() -> Result<()> {
-        let dest = XorName::random();
-        let dest_section_pk = SecretKey::random().public_key();
-
-        let wire_msg = WireMsg::new_ping_msg(dest, dest_section_pk);
-        let serialized = wire_msg.serialize()?;
-
-        // test deserialisation of header
-        let deserialized = WireMsg::from(serialized)?;
-        assert_eq!(deserialized, wire_msg);
-        assert_eq!(deserialized.dest(), dest);
-        assert_eq!(deserialized.dest_section_pk(), dest_section_pk);
-
-        // test deserialisation of payload
-        assert_eq!(
-            deserialized.to_message()?,
-            MessageType::Ping(DestInfo {
-                dest,
-                dest_section_pk
-            })
-        );
-
-        Ok(())
-    }
-
     #[test]
     fn serialisation_section_info_msg() -> Result<()> {
         let dest = XorName::random();
@@ -331,6 +319,7 @@ mod tests {
         // test deserialisation of header
         let deserialized = WireMsg::from(serialized)?;
         assert_eq!(deserialized, wire_msg);
+        assert_eq!(deserialized.msg_id(), wire_msg.msg_id());
         assert_eq!(deserialized.dest(), dest);
         assert_eq!(deserialized.dest_section_pk(), dest_section_pk);
         assert_eq!(deserialized.src_section_pk(), None);
@@ -372,6 +361,7 @@ mod tests {
         // test deserialisation of header
         let deserialized = WireMsg::from(serialized)?;
         assert_eq!(deserialized, wire_msg);
+        assert_eq!(deserialized.msg_id(), wire_msg.msg_id());
         assert_eq!(deserialized.dest(), dest);
         assert_eq!(deserialized.dest_section_pk(), dest_section_pk);
         assert_eq!(deserialized.src_section_pk(), None);
@@ -397,6 +387,7 @@ mod tests {
         // test deserialisation of header
         let deserialized = WireMsg::from(serialized)?;
         assert_eq!(deserialized, wire_msg_with_src_pk);
+        assert_eq!(deserialized.msg_id(), wire_msg_with_src_pk.msg_id());
         assert_eq!(deserialized.dest(), dest);
         assert_eq!(deserialized.dest_section_pk(), dest_section_pk);
         assert_eq!(deserialized.src_section_pk(), Some(src_section_pk));
