@@ -7,7 +7,7 @@
 // specific language governing permissions and limitations relating to use of the SAFE Network
 // Software.
 
-use super::{Error, Result};
+use crate::{Error, MessageId, Result, MESSAGE_ID_LEN};
 use bytes::Bytes;
 use cookie_factory::{
     bytes::{be_u16, be_u8},
@@ -26,6 +26,7 @@ const MESSAGING_PROTO_VERSION: u16 = 1u16;
 // This header contains the information needed to deserialize the payload.
 #[derive(Debug, PartialEq)]
 pub(crate) struct WireMsgHeader {
+    msg_id: MessageId,
     header_size: u16,
     version: u16,
     kind: MessageKind,
@@ -42,8 +43,13 @@ const HDR_VERSION_BYTES_START: usize = HDR_SIZE_BYTES_LEN;
 const HDR_VERSION_BYTES_LEN: usize = size_of::<u16>();
 const HDR_VERSION_BYTES_END: usize = HDR_VERSION_BYTES_START + HDR_VERSION_BYTES_LEN;
 
+// Bytes index in the header for the 'msg_id' field
+const HDR_MSG_ID_BYTES_START: usize = HDR_VERSION_BYTES_END;
+const HDR_MSG_ID_BYTES_LEN: usize = MESSAGE_ID_LEN;
+const HDR_MSG_ID_BYTES_END: usize = HDR_MSG_ID_BYTES_START + HDR_MSG_ID_BYTES_LEN;
+
 // Bytes index in the header for the 'kind' field
-const HDR_KIND_BYTES_START: usize = HDR_VERSION_BYTES_END;
+const HDR_KIND_BYTES_START: usize = HDR_MSG_ID_BYTES_END;
 const HDR_KIND_BYTES_LEN: usize = 1;
 
 // Bytes index in the header for the 'dest' field
@@ -63,6 +69,7 @@ const HDR_SRC_PK_BYTES_END: usize = HDR_SRC_PK_BYTES_START + HDR_SRC_PK_BYTES_LE
 
 const HEADER_MIN_SIZE: usize = HDR_SIZE_BYTES_LEN
     + HDR_VERSION_BYTES_LEN
+    + HDR_MSG_ID_BYTES_LEN
     + HDR_KIND_BYTES_LEN
     + HDR_DEST_BYTES_LEN
     + HDR_DEST_PK_BYTES_LEN;
@@ -70,12 +77,14 @@ const HEADER_MIN_SIZE: usize = HDR_SIZE_BYTES_LEN
 impl WireMsgHeader {
     // Instantiate a WireMsgHeader as per current supported version.
     pub fn new(
+        msg_id: MessageId,
         kind: MessageKind,
         dest: XorName,
         dest_section_pk: PublicKey,
         src_section_pk: Option<PublicKey>,
     ) -> Self {
         Self {
+            msg_id,
             header_size: Self::bytes_size(src_section_pk.is_some()) as u16,
             version: MESSAGING_PROTO_VERSION,
             kind,
@@ -85,6 +94,11 @@ impl WireMsgHeader {
         }
     }
 
+    // Return the message id of this message
+    pub fn msg_id(&self) -> MessageId {
+        self.msg_id
+    }
+
     // Return the kind of this message
     pub fn kind(&self) -> MessageKind {
         self.kind
@@ -144,6 +158,11 @@ impl WireMsgHeader {
             return Err(Error::UnsupportedVersion(version));
         }
 
+        // ...read the message id bytes
+        let mut msg_id_bytes = [0; HDR_MSG_ID_BYTES_LEN];
+        msg_id_bytes[0..].copy_from_slice(&bytes[HDR_MSG_ID_BYTES_START..HDR_MSG_ID_BYTES_END]);
+        let msg_id = MessageId::with(msg_id_bytes);
+
         // ...read the message kind value (only 1 byte)
         let kind = MessageKind::try_from(bytes[HDR_KIND_BYTES_START])?;
 
@@ -182,6 +201,7 @@ impl WireMsgHeader {
         };
 
         let header = Self {
+            msg_id,
             header_size,
             version,
             kind,
@@ -206,13 +226,22 @@ impl WireMsgHeader {
         })?;
 
         // Now let's write the serialisation protocol version bytes
-        let (buf_at_msg_kind, _) = gen(be_u16(self.version), buf_at_version).map_err(|err| {
+        let (buf_at_msg_id, _) = gen(be_u16(self.version), buf_at_version).map_err(|err| {
             Error::Serialisation(format!(
                 "version field couldn't be serialized in header: {}",
                 err
             ))
         })?;
 
+        // Write the message id bytes
+        let (buf_at_msg_kind, _) =
+            gen(slice(self.msg_id.as_ref()), buf_at_msg_id).map_err(|err| {
+                Error::Serialisation(format!(
+                    "message id field couldn't be serialized in header: {}",
+                    err
+                ))
+            })?;
+
         // ...now let's write the value signaling the message kind
         let (buf_at_dest, _) = gen(be_u8(self.kind.into()), buf_at_msg_kind).map_err(|err| {
             Error::Serialisation(format!(
@@ -286,7 +315,6 @@ impl WireMsgHeader {
 // is part of the WireMsgHeader.
 #[derive(Debug, Clone, Copy, PartialEq)]
 pub(crate) enum MessageKind {
-    Ping,
     SectionInfo,
     Client,
     Routing,
@@ -295,18 +323,16 @@ pub(crate) enum MessageKind {
 
 // Bytes values used for each of the kind of messages
 // when written to the message header
-const PING_KIND: u8 = 0x00;
-const SECTION_INFO_KIND: u8 = 0x01;
-const CLIENT_MSG_KIND: u8 = 0x02;
-const ROUTING_MSG_KIND: u8 = 0x03;
-const NODE_MSG_KIND: u8 = 0x04;
+const SECTION_INFO_KIND: u8 = 0x00;
+const CLIENT_MSG_KIND: u8 = 0x01;
+const ROUTING_MSG_KIND: u8 = 0x02;
+const NODE_MSG_KIND: u8 = 0x03;
 
 impl TryFrom<u8> for MessageKind {
     type Error = super::Error;
 
     fn try_from(input: u8) -> Result<Self, Self::Error> {
         match input {
-            PING_KIND => Ok(Self::Ping),
             SECTION_INFO_KIND => Ok(Self::SectionInfo),
             CLIENT_MSG_KIND => Ok(Self::Client),
             ROUTING_MSG_KIND => Ok(Self::Routing),
@@ -319,7 +345,6 @@ impl TryFrom<u8> for MessageKind {
 impl From<MessageKind> for u8 {
     fn from(kind: MessageKind) -> u8 {
         match kind {
-            MessageKind::Ping => PING_KIND,
             MessageKind::SectionInfo => SECTION_INFO_KIND,
             MessageKind::Client => CLIENT_MSG_KIND,
             MessageKind::Routing => ROUTING_MSG_KIND,
@@ -336,7 +361,6 @@ mod tests {
     #[test]
     fn message_kind_from_u8() -> Result<()> {
         for &(kind, byte) in &[
-            (MessageKind::Ping, PING_KIND),
             (MessageKind::SectionInfo, SECTION_INFO_KIND),
             (MessageKind::Client, CLIENT_MSG_KIND),
             (MessageKind::Routing, ROUTING_MSG_KIND),
